==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/workflows/CronScheduleOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) CRON schedule options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.776Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.CronScheduleOptions")
@software.amazon.jsii.Jsii.Proxy(CronScheduleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CronScheduleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * @see https://pubs.opengroup.org/onlinepubs/9699919799/utilities/crontab.html#tag_20_25_07
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getCron();

    /**
     * @return a {@link Builder} of {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CronScheduleOptions> {
        java.lang.String cron;

        /**
         * Sets the value of {@link CronScheduleOptions#getCron}
         * @param cron the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cron(java.lang.String cron) {
            this.cron = cron;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CronScheduleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CronScheduleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CronScheduleOptions {
        private final java.lang.String cron;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cron = software.amazon.jsii.Kernel.get(this, "cron", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cron = java.util.Objects.requireNonNull(builder.cron, "cron is required");
        }

        @Override
        public final java.lang.String getCron() {
            return this.cron;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cron", om.valueToTree(this.getCron()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.CronScheduleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CronScheduleOptions.Jsii$Proxy that = (CronScheduleOptions.Jsii$Proxy) o;

            return this.cron.equals(that.cron);
        }

        @Override
        public final int hashCode() {
            int result = this.cron.hashCode();
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/workflows/CronScheduleOptions.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) CRON schedule options.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.446Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.CronScheduleOptions")
@software.amazon.jsii.Jsii.Proxy(CronScheduleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CronScheduleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * @see <a href="https://pubs.opengroup.org/onlinepubs/9699919799/utilities/crontab.html#tag_20_25_07">https://pubs.opengroup.org/onlinepubs/9699919799/utilities/crontab.html#tag_20_25_07</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getCron();

    /**
     * @return a {@link Builder} of {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CronScheduleOptions> {
        java.lang.String cron;

        /**
         * Sets the value of {@link CronScheduleOptions#getCron}
         * @param cron the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cron(java.lang.String cron) {
            this.cron = cron;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CronScheduleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CronScheduleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CronScheduleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CronScheduleOptions {
        private final java.lang.String cron;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cron = software.amazon.jsii.Kernel.get(this, "cron", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cron = java.util.Objects.requireNonNull(builder.cron, "cron is required");
        }

        @Override
        public final java.lang.String getCron() {
            return this.cron;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cron", om.valueToTree(this.getCron()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.CronScheduleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CronScheduleOptions.Jsii$Proxy that = (CronScheduleOptions.Jsii$Proxy) o;

            return this.cron.equals(that.cron);
        }

        @Override
        public final int hashCode() {
            int result = this.cron.hashCode();
            return result;
        }
    }
}
